@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: link_ser.c 3720 2007-08-24 20:57:50Z roms $ */
+/* $Id: link_ser.c 3932 2007-10-18 19:47:09Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -50,7 +50,7 @@ static int ser_prepare(CableHandle *h)
 	// detect OS 
 	if(win32_check_os() == WIN_NT)
 	{
-		if(!win32_check_dha())
+		if(win32_check_dha())
 		{
 			free(h->device); h->device = NULL;
 			return ERR_DHA_NOT_FOUND;
@@ -58,7 +58,7 @@ static int ser_prepare(CableHandle *h)
 	}
 	else if(win32_check_os() == WIN_64)
 	{
-		if(!win32_check_rwp())
+		if(win32_check_rwp())
 		{
 			free(h->device); h->device = NULL;
 			return ERR_DHA_NOT_FOUND;
@@ -82,11 +82,6 @@ static int ser_open(CableHandle *h)
 	TRYC(io_open(com_out));
 	TRYC(io_open(com_in));
 
-	TRYC(ser_reset(h));
-#ifdef OPEN_DELAYED
-	Sleep(2000);	// needs this because serial lines can be low at startup
-#endif
-
 	return 0;
 }
 
